
typedef union 	{
	long	lval;
	char	sval[100];
	} EDIFLSTYPE;
extern EDIFLSTYPE edifllval;
# define T_EDIF 257
# define T_EDIFVERSION 258
# define T_EDIFLEVEL 259
# define T_LIBRARY 260
# define T_TECHNOLOGY 261
# define T_CELLTYPE 262
# define T_CELLTYPE_GENERIC 263
# define T_CELL 264
# define T_CELLTYPE_TIE 265
# define T_CELLTYPE_RIPPER 266
# define T_PROPERTY 267
# define T_VIEW 268
# define T_VIEWTYPE 269
# define T_INTERFACE 270
# define T_CONTENTS 271
# define T_NET 272
# define T_JOINED 273
# define T_INSTANCE 274
# define T_VIEWREF 275
# define T_CELLREF 276
# define T_PORT 277
# define T_DIRECTION 278
# define T_INOUT 279
# define T_INPUT 280
# define T_PORTREF 281
# define T_NETLIST 282
# define T_KEYWORDMAP 283
# define T_STATUS 284
# define T_KEYWORDLEVEL 285
# define T_EXTERNAL 286
# define T_LIBRARYREF 287
# define T_IDENT 288
# define T_OUTPUT 289
# define T_INSTANCEREF 290
# define T_MEMBER 291
# define T_ARRAY 292
# define T_RENAME 293
# define T_NAME 294
# define T_STRING 295
# define T_INTEGER 296
